inputSequence {
    header,
    SHA512
},
subtypeText,
validationResults {
    level,
    message
},
alignedGeneSequences {
    firstAA, lastAA,
    gene { name, length },
    mutations {
        consensus,
        position,
        AAs,
        isInsertion,
        isDeletion,
        isApobecDRM
    },
    SDRMs:mutations(filterOptions:[SDRM]) {
        text
    },
    alignedNAs,
    alignedAAs,
    prettyPairwise {
        positionLine,
        refAALine,
        alignedNAsLine,
        mutationLine
    }
},
drugResistance {
    version { text, publishDate },
    gene { name },
    drugScores {
        drugClass { name },
        drug {
            name,
            displayAbbr,
        },
        score,
        partialScores {
            mutations {
                text,
                primaryType,
                comments { type, text }
            },
            score
        },
        text
    }
}
